<?php

namespace Drupal\book_pdfs\Event;

use Symfony\Contracts\EventDispatcher\Event;
use Dompdf\Dompdf;
use Drupal\node\Entity\Node;

/**
 * Class BookPdfsPreGenerateEvent.
 *
 * @package Drupal\book_pdfs\Event
 */
class BookPdfsPreGenerateEvent extends Event {

  /**
   * The html.
   *
   * @var string
   */
  public $html;

  /**
   * The Dompdf object.
   *
   * @var \Dompdf\Dompdf
   */
  protected $pdf;

  /**
   * The Dompdf global options.
   *
   * @var array
   */
  protected $globalOptions;

  /**
   * The Book node.
   *
   * @var \Drupal\node\Entity\Node
   */
  protected $book;

  /**
   * The language code.
   *
   * @var string
   */
  protected $langcode;

  /**
   * BookPdfsPreGenerateEvent constructor.
   *
   * @param \Drupal\node\Entity\Node $book
   *   The Book node.
   * @param \Dompdf\Dompdf $pdf
   *   The Dompdf object.
   * @param array $default_options
   *   The default Dompdf global options.
   * @param string $langcode
   *   The language code.
   */
  public function __construct(Node $book, Dompdf $pdf, array $default_options, $langcode) {
    $this->pdf = $pdf;
    $this->globalOptions = $default_options;
    $this->langcode = $langcode;
    if ($book->hasTranslation($langcode)) {
      $book = $book->getTranslation($langcode);
    }
    if (isset($default_options['html'])) {
      $this->setHtml($default_options['html']);
    }
    $this->book = $book;
  }

  /**
   * Get the html.
   *
   * @return string
   *   The html.
   */
  public function getHtml() {
    return $this->html;
  }

  /**
   * Get the PDF object.
   *
   * @return \Dompdf\Dompdf
   *   The Dompdf object.
   */
  public function getPdf() {
    return $this->pdf;
  }

  /**
   * Get the global Dompdf options.
   *
   * @return array
   *   The default options.
   */
  public function getGlobalOptions() {
    return $this->globalOptions;
  }

  /**
   * Set the html.
   *
   * @param string $html.
   *   The value.
   */
  public function setHtml($html) {
    $this->html = $html;
  }

  /**
   * Set the global Dompdf options.
   *
   * @param array $options
   *   The new global options.
   */
  public function setGlobalOptions(array $options) {
    $this->globalOptions = $options;
  }

  /**
   * Get the Book node.
   *
   * @return \Drupal\node\Entity\Node
   *   The Book node.
   */
  public function getBook() {
    return $this->book;
  }

  /**
   * Get the language code.
   *
   * @return string
   *   The language code.
   */
  public function getLangcode() {
    return $this->langcode;
  }
}

